/*
Erstellt von:             Johannes Beißwenger, Simon Gaiser
Erstellt im Zeitraum:     Oktober 2017
Aufgaben des Programms:   Das Programm Überwacht den Druckablauf des 3D-Druckes der staatlichen Majolika.
                          Nach dem Fertigstellen eines Druckauftrages wird ein Förderband angesteuert, welches das fertige Tonobjekt aus dem Druckraum fährt.
                          Anschließend kann ein neuer Druckauftrag gestartet werden.
 */

// Inkludierung der Bibliotheken
//------------------------------------------------------------------------------//
#include <Wire.h>                 // I2C
#include <Adafruit_GFX.h>         // OLED
#include <Adafruit_SSD1306.h>     // Graphic

//Definition der Pinbelegung / Namensgebung
//-------------------------------------------------------------------------------//
#define SignalDrucker 25                 // Endschalter am 3D-Drucker
#define SignalFoerderband 32             // Lichtschranke am Förderband
#define FoerderbandFahren 5              // Steuersignal für Förderband fahren

#define OLED_RESET 4                     // not used / nicht genutzt bei diesem Display

// Initialisierungen
//------------------------------------------------------------------------------//
Adafruit_SSD1306 display(OLED_RESET);

// Funktionen
//------------------------------------------------------------------------------//
void FoerderbandVoll();                   
void DruckBetrieb();                      

// Definition der Pins
//------------------------------------------------------------------------------//
void setup()
{
  Serial.begin(9600);                           // serielle Schnittstelle

  //Oled Initialisierung
  display.begin(SSD1306_SWITCHCAPVCC, 0x3C);
  display.display();
  display.clearDisplay();
  display.setTextSize(1);
  display.setTextColor(INVERSE);

  //Ausgänge
  pinMode(FoerderbandFahren, OUTPUT);           // Steuersignal Förderband fahren

  //Eingänge
  pinMode(SignalDrucker, INPUT_PULLUP);         // Eingangssignal 3D-Drucker, Achtung PULLUP -> Taster gegen Masse
  pinMode(SignalFoerderband, INPUT_PULLUP);     // Eingangssignal Lichtschranke Förderband, Achtung PULLUP ->  Taster gegen Masse
}

// Globale Variablen
//-----------------------------------------------------------------------------//
unsigned int TextS = 1;       // Textgroeße

//-----------------------------------------------------------------------------//
void loop()
{
   if (digitalRead(SignalFoerderband) == LOW)
  {
    FoerderbandVoll();
  }
  else
  {
    DruckBetrieb();
  }
}

//-----------------------------------------------------------------------------//
void FoerderbandVoll()
{
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(TextS);
  display.println("Foerderband Voll");                      
  display.println();       
  display.println("Bitte Tonobjekte von Foerderband entnehmen");
  display.display();
}

void DruckBetrieb()
{
  int val;
  int buttonState = digitalRead(SignalDrucker);     // Anfangszustand lesen
  int buttonPresses = 0;
  
  while (digitalRead(SignalFoerderband) == HIGH)
  {
    val = digitalRead(SignalDrucker);               // Eingabewert lesen und in val speichern
    if (val != buttonState)                         // Der Zustand des Schalters hat sich verändert
    { 
      if (val == LOW)                               // Ist der Schalter gedrückt?
      { 
        buttonPresses++;                            // Tastendrücke zählen
       }
    } 
    buttonState = val;                              // Den Zustand merken
    if (buttonPresses == 0)                         // kein Druckersignal erhalten
    { 
      display.clearDisplay();
      display.setCursor(0, 0);
      display.setTextSize(TextS);
      display.println("Anlage Bereit");
      display.display();
    }
    else if (buttonPresses == 1)                    // Drucker fährt von Grundstellung in Arbeitsposition 
    {
      display.clearDisplay();
      display.setCursor(0, 0);
      display.setTextSize(TextS);
      display.println("wird gedruckt");
      display.println("??Druckzeit??");
      display.display();
     }
    else if (buttonPresses == 2)                    // Drucker ist fertig, fährt von Arbeitsposition in Grundstellung
    {
      display.clearDisplay();
      display.setCursor(0, 0);
      display.setTextSize(TextS);
      display.println("Druck beendet");
      display.println("Foerderband fahren");
      display.display();
      digitalWrite(FoerderbandFahren, HIGH);        // Förderband ansteuern
      delay(2000);                                  // Verfahrweg des Förderbandes muss noch eingepflegt werden
      digitalWrite(FoerderbandFahren, LOW);
      buttonPresses = 0;
    }
  }
}

